s3fs
====

[|Build Status|](https://github.com/fsspec/s3fs/actions)
[|Documentation|](https://s3fs.readthedocs.io/en/latest/?badge=latest)

S3FS builds on [aiobotocore](https://aiobotocore.readthedocs.io/en/latest/)
to provide a convenient Python filesystem interface for S3.


Support
-------

Work on this repository is supported in part by:

"Anaconda, Inc. - Advancing AI through open source."

<a href="https://anaconda.com/"><img src="https://camo.githubusercontent.com/b8555ef2222598ed37ce38ac86955febbd25de7619931bb7dd3c58432181d3b6/68747470733a2f2f626565776172652e6f72672f636f6d6d756e6974792f6d656d626572732f616e61636f6e64612f616e61636f6e64612d6c617267652e706e67" alt="anaconda logo" width="40%"/></a>
